package
Version:
v6.10.9-aug.4
Opens a new window with list of versions in this module.
Published: May 14, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package gemini provides in-provider request normalization for Gemini API.
It ensures incoming v1beta requests meet minimal schema requirements
expected by Google's Generative Language API.
-
func ConvertGeminiRequestToGemini(_ string, inputRawJSON []byte, _ bool) []byte
-
func PassthroughGeminiResponseNonStream(_ context.Context, _ string, _, _, rawJSON []byte, _ *any) []byte
-
func PassthroughGeminiResponseStream(_ context.Context, _ string, _, _, rawJSON []byte, _ *any) [][]byte
ConvertGeminiRequestToGemini normalizes Gemini v1beta requests.
- Adds a default role for each content if missing or invalid.
The first message defaults to "user", then alternates user/model when needed.
It keeps the payload otherwise unchanged.
PassthroughGeminiResponseNonStream forwards Gemini responses unchanged.
PassthroughGeminiResponseStream forwards Gemini responses unchanged.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.