Documentation
¶
Overview ¶
Package diff computes human-readable diffs for auth file field changes.
Index ¶
- func BuildAuthChangeDetails(oldAuth, newAuth *coreauth.Auth) []string
- func BuildConfigChangeDetails(oldCfg, newCfg *config.Config) []string
- func ComputeClaudeModelsHash(models []config.ClaudeModel) string
- func ComputeCodexModelsHash(models []config.CodexModel) string
- func ComputeExcludedModelsHash(excluded []string) string
- func ComputeGeminiModelsHash(models []config.GeminiModel) string
- func ComputeOpenAICompatModelsHash(models []config.OpenAICompatibilityModel) string
- func ComputeVertexCompatModelsHash(models []config.VertexCompatModel) string
- func OAuthExcludedModelChanges(oldMap, newMap map[string][]string) ([]string, []string)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildAuthChangeDetails ¶
BuildAuthChangeDetails computes a redacted, human-readable list of auth field changes. Only prefix, proxy_url, and disabled fields are tracked; sensitive data is never printed.
func BuildConfigChangeDetails ¶
BuildConfigChangeDetails computes a redacted, human-readable list of config changes. Secrets are never printed; only structural or non-sensitive fields are surfaced.
func ComputeClaudeModelsHash ¶
func ComputeClaudeModelsHash(models []config.ClaudeModel) string
ComputeClaudeModelsHash returns a stable hash for Claude model aliases.
func ComputeCodexModelsHash ¶
func ComputeCodexModelsHash(models []config.CodexModel) string
ComputeCodexModelsHash returns a stable hash for Codex model aliases.
func ComputeExcludedModelsHash ¶
ComputeExcludedModelsHash returns a normalized hash for excluded model lists.
func ComputeGeminiModelsHash ¶
func ComputeGeminiModelsHash(models []config.GeminiModel) string
ComputeGeminiModelsHash returns a stable hash for Gemini model aliases.
func ComputeOpenAICompatModelsHash ¶
func ComputeOpenAICompatModelsHash(models []config.OpenAICompatibilityModel) string
ComputeOpenAICompatModelsHash returns a stable hash for OpenAI-compat models. Used to detect model list changes during hot reload.
func ComputeVertexCompatModelsHash ¶
func ComputeVertexCompatModelsHash(models []config.VertexCompatModel) string
ComputeVertexCompatModelsHash returns a stable hash for Vertex-compatible models.
Types ¶
This section is empty.